% logistic function
% Amund N. L?vik 2012
% Luis Felipe Vasquez Correa 2016
%
%
%                      (C1 - C0)
%      y(x)= C0 +  -------------------
%                  1 + e^(-(t-ti)/tau)
%

% Example: logistic([1950;18],(1800:2100)'); will return a vector y with
% values for a logistic curve starting at C0 and converging to C1 as given
% in this file, with an inflection time in 1950 and a transition time of
% around 18*6 = 108 years.

function y=logistic(b,x,c) % b vertical vector of coefficients, x vector of observation points
C0=c(1);
C1=c(2);
ti=b(1);    % Inflection time
tau = b(2); % Transition time coefficient

y = (C1 -C0)./(1 + exp(-(x-ti)/tau)) + C0; % y values calculated for the given input coefficients and observation points

end
